@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011 Guus Sliepen
-Copyright (C) 2015 Julian Marchant
+Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -40,22 +40,26 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "bullet.h"
 #include "cargo.h"
 #include "collectable.h"
+#include "colors.h"
+#include "cutscene.h"
 #include "engine.h"
+#include "event.h"
 #include "explosion.h"
 #include "game.h"
-#include "graphics.h"
-#include "init.h"
+#include "gfx.h"
 #include "intermission.h"
 #include "loadSave.h"
 #include "messages.h"
 #include "misc.h"
 #include "missions.h"
 #include "player.h"
+#include "renderer.h"
 #include "resources.h"
-#include "script.h"
+#include "screen.h"
 #include "ship.h"
 #include "shop.h"
 #include "title.h"
 #include "weapons.h"
+#include "window.h"
 
 #endif
