@@ -1,7 +1,7 @@
 /*
 Copyright (C) 2003 Parallel Realities
 Copyright (C) 2011, 2012 Guus Sliepen
-Copyright (C) 2015 Julian Marchant
+Copyright (C) 2015, 2016 onpon4 <onpon4@riseup.net>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -21,7 +21,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define AUDIO_H
 
 void audio_loadSounds();
-void audio_playSound(int sid, float x);
+void audio_playSound(int sid, float x, float y);
 void audio_haltMusic();
 void audio_pauseMusic();
 void audio_resumeMusic();
